@@ -12,36 +12,52 @@
 #
 ##############################################################################
 """
-$Id: tests.py 72085 2007-01-18 01:02:49Z rogerineichen $
+$Id: tests.py 97278 2009-02-25 23:56:48Z nadako $
 """
 __docformat__ = "reStructuredText"
 
 import unittest
+import itertools
 
 from zope.testing import doctest
 from zope.testing.doctestunit import DocFileSuite
 from zope.app.testing import setup
+from zope.configuration import xmlconfig
 
+import z3c.ptcompat
+from z3c.ptcompat.testing import OutputChecker
 
 def setUp(test):
     root = setup.placefulSetUp(site=True)
     test.globs['root'] = root
 
-
 def tearDown(test):
     setup.placefulTearDown()
 
+def setUpZPT(suite):
+    z3c.ptcompat.config.disable()
+    setUp(suite)
+    
+def setUpZ3CPT(suite):
+    z3c.ptcompat.config.enable()
+    setUp(suite)
+    xmlconfig.XMLConfig('configure.zcml', z3c.pt)()
 
 def test_suite():
-    return unittest.TestSuite((
+    checker = OutputChecker(doctest)
+    tests = ((
         DocFileSuite('README.txt',
             setUp=setUp, tearDown=tearDown,
             optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
+            checker=checker,
             ),
         DocFileSuite('zcml.txt', setUp=setUp, tearDown=tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,),
-        ))
+            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
+            checker=checker,
+            ),
+        ) for setUp in (setUpZPT, setUpZ3CPT,))
 
+    return unittest.TestSuite(itertools.chain(*tests))
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
